package design_pattern.flyweight;

import java.lang.reflect.Method;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class Introspector {
	private static final Map<Class<?>, BeanInfo> BEAN_INFO_CACHE = new ConcurrentHashMap<Class<?>, BeanInfo>();

	public static BeanInfo getBeanInfo(Class<?> clazz) {
		if (BEAN_INFO_CACHE.containsKey(clazz) == true) {
			return BEAN_INFO_CACHE.get(clazz);
		}
		BeanInfo ret = createBeanInfo(clazz);
		BEAN_INFO_CACHE.put(clazz, ret);
		return ret;
	}

	private static BeanInfo createBeanInfo(Class<?> clazz) {
		BeanInfo ret = new BeanInfo();
		Method[] methods = clazz.getMethods();
		for (Method method : methods) {
			String methodName = method.getName();
			String propertyName = Character
					.toLowerCase(methodName.charAt(3))
					+ methodName.substring(4, methodName
							.length());
			if ("getClass".equals(methodName) == true) {
			} else if (methodName.startsWith("get") == true) {
				PropertyDescriptor pd = ret
						.getPropertyDescriptor(propertyName);
				pd.setReadMethod(method);
			} else if (methodName.startsWith("set") == true) {
				PropertyDescriptor pd = ret
						.getPropertyDescriptor(propertyName);
				pd.setWriteMethod(method);
			}
		}
		return ret;
	}
}
