package design_pattern.proxy;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Date;
import java.sql.NClob;
import java.sql.Ref;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.RowId;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.SQLXML;
import java.sql.Statement;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Map;

public class OracleResultSet implements ResultSet {
	/** WAVE DASH */
	public static final int WAVE_DASH = 0x301c;

	/** FULLWIDTH TILDE */
	public static final int FULLWIDTH_TILDE = 0xff5e;

	private ResultSet delegator;

	public OracleResultSet(ResultSet delegator) {
		this.delegator = delegator;
	}

	public String getString(int columnIndex) throws SQLException {
		String result = delegator.getString(columnIndex);
		return convert(result);
	}

	public String getString(String columnLabel)
			throws SQLException {
		String result = delegator.getString(columnLabel);
		return convert(result);
	}

	private String convert(String source) {
		if (source == null) {
			return null;
		}
		StringBuilder result = new StringBuilder(source.length());
		for (int i = 0; i < source.length(); i++) {
			char ch = source.charAt(i);
			ch = convert(ch);
			result.append(ch);
		}

		return result.toString();
	}

	private char convert(char soruce) {
		switch (soruce) {
		case WAVE_DASH:
			return FULLWIDTH_TILDE;
		default:
			return soruce;
		}
	}

	public boolean isWrapperFor(Class<?> iface)
			throws SQLException {
		return delegator.isWrapperFor(iface);
	}

	public <T> T unwrap(Class<T> iface) throws SQLException {
		return delegator.unwrap(iface);
	}

	public boolean absolute(int row) throws SQLException {
		return delegator.absolute(row);
	}

	public void afterLast() throws SQLException {
		delegator.afterLast();
	}

	public void beforeFirst() throws SQLException {
		delegator.beforeFirst();
	}

	public void cancelRowUpdates() throws SQLException {
		delegator.cancelRowUpdates();
	}

	public void clearWarnings() throws SQLException {
		delegator.clearWarnings();
	}

	public void close() throws SQLException {
		delegator.close();
	}

	public void deleteRow() throws SQLException {
		delegator.deleteRow();
	}

	public int findColumn(String columnLabel)
			throws SQLException {
		return delegator.findColumn(columnLabel);
	}

	public boolean first() throws SQLException {
		return delegator.first();
	}

	public Array getArray(int columnIndex) throws SQLException {
		return delegator.getArray(columnIndex);
	}

	public Array getArray(String columnLabel)
			throws SQLException {
		return delegator.getArray(columnLabel);
	}

	public InputStream getAsciiStream(int columnIndex)
			throws SQLException {
		return delegator.getAsciiStream(columnIndex);
	}

	public InputStream getAsciiStream(String columnLabel)
			throws SQLException {
		return delegator.getAsciiStream(columnLabel);
	}

	@SuppressWarnings("deprecation")
	public BigDecimal getBigDecimal(int columnIndex, int scale)
			throws SQLException {
		return delegator.getBigDecimal(columnIndex, scale);
	}

	public BigDecimal getBigDecimal(int columnIndex)
			throws SQLException {
		return delegator.getBigDecimal(columnIndex);
	}

	@SuppressWarnings("deprecation")
	public BigDecimal getBigDecimal(String columnLabel, int scale)
			throws SQLException {
		return delegator.getBigDecimal(columnLabel, scale);
	}

	public BigDecimal getBigDecimal(String columnLabel)
			throws SQLException {
		return delegator.getBigDecimal(columnLabel);
	}

	public InputStream getBinaryStream(int columnIndex)
			throws SQLException {
		return delegator.getBinaryStream(columnIndex);
	}

	public InputStream getBinaryStream(String columnLabel)
			throws SQLException {
		return delegator.getBinaryStream(columnLabel);
	}

	public Blob getBlob(int columnIndex) throws SQLException {
		return delegator.getBlob(columnIndex);
	}

	public Blob getBlob(String columnLabel) throws SQLException {
		return delegator.getBlob(columnLabel);
	}

	public boolean getBoolean(int columnIndex)
			throws SQLException {
		return delegator.getBoolean(columnIndex);
	}

	public boolean getBoolean(String columnLabel)
			throws SQLException {
		return delegator.getBoolean(columnLabel);
	}

	public byte getByte(int columnIndex) throws SQLException {
		return delegator.getByte(columnIndex);
	}

	public byte getByte(String columnLabel) throws SQLException {
		return delegator.getByte(columnLabel);
	}

	public byte[] getBytes(int columnIndex) throws SQLException {
		return delegator.getBytes(columnIndex);
	}

	public byte[] getBytes(String columnLabel)
			throws SQLException {
		return delegator.getBytes(columnLabel);
	}

	public Reader getCharacterStream(int columnIndex)
			throws SQLException {
		return delegator.getCharacterStream(columnIndex);
	}

	public Reader getCharacterStream(String columnLabel)
			throws SQLException {
		return delegator.getCharacterStream(columnLabel);
	}

	public Clob getClob(int columnIndex) throws SQLException {
		return delegator.getClob(columnIndex);
	}

	public Clob getClob(String columnLabel) throws SQLException {
		return delegator.getClob(columnLabel);
	}

	public int getConcurrency() throws SQLException {
		return delegator.getConcurrency();
	}

	public String getCursorName() throws SQLException {
		return delegator.getCursorName();
	}

	public Date getDate(int columnIndex, Calendar cal)
			throws SQLException {
		return delegator.getDate(columnIndex, cal);
	}

	public Date getDate(int columnIndex) throws SQLException {
		return delegator.getDate(columnIndex);
	}

	public Date getDate(String columnLabel, Calendar cal)
			throws SQLException {
		return delegator.getDate(columnLabel, cal);
	}

	public Date getDate(String columnLabel) throws SQLException {
		return delegator.getDate(columnLabel);
	}

	public double getDouble(int columnIndex) throws SQLException {
		return delegator.getDouble(columnIndex);
	}

	public double getDouble(String columnLabel)
			throws SQLException {
		return delegator.getDouble(columnLabel);
	}

	public int getFetchDirection() throws SQLException {
		return delegator.getFetchDirection();
	}

	public int getFetchSize() throws SQLException {
		return delegator.getFetchSize();
	}

	public float getFloat(int columnIndex) throws SQLException {
		return delegator.getFloat(columnIndex);
	}

	public float getFloat(String columnLabel)
			throws SQLException {
		return delegator.getFloat(columnLabel);
	}

	public int getHoldability() throws SQLException {
		return delegator.getHoldability();
	}

	public int getInt(int columnIndex) throws SQLException {
		return delegator.getInt(columnIndex);
	}

	public int getInt(String columnLabel) throws SQLException {
		return delegator.getInt(columnLabel);
	}

	public long getLong(int columnIndex) throws SQLException {
		return delegator.getLong(columnIndex);
	}

	public long getLong(String columnLabel) throws SQLException {
		return delegator.getLong(columnLabel);
	}

	public ResultSetMetaData getMetaData() throws SQLException {
		return delegator.getMetaData();
	}

	public Reader getNCharacterStream(int columnIndex)
			throws SQLException {
		return delegator.getNCharacterStream(columnIndex);
	}

	public Reader getNCharacterStream(String columnLabel)
			throws SQLException {
		return delegator.getNCharacterStream(columnLabel);
	}

	public NClob getNClob(int columnIndex) throws SQLException {
		return delegator.getNClob(columnIndex);
	}

	public NClob getNClob(String columnLabel)
			throws SQLException {
		return delegator.getNClob(columnLabel);
	}

	public String getNString(int columnIndex)
			throws SQLException {
		return delegator.getNString(columnIndex);
	}

	public String getNString(String columnLabel)
			throws SQLException {
		return delegator.getNString(columnLabel);
	}

	public Object getObject(int columnIndex,
			Map<String, Class<?>> map) throws SQLException {
		return delegator.getObject(columnIndex, map);
	}

	public Object getObject(int columnIndex) throws SQLException {
		return delegator.getObject(columnIndex);
	}

	public Object getObject(String columnLabel,
			Map<String, Class<?>> map) throws SQLException {
		return delegator.getObject(columnLabel, map);
	}

	public Object getObject(String columnLabel)
			throws SQLException {
		return delegator.getObject(columnLabel);
	}

	public Ref getRef(int columnIndex) throws SQLException {
		return delegator.getRef(columnIndex);
	}

	public Ref getRef(String columnLabel) throws SQLException {
		return delegator.getRef(columnLabel);
	}

	public int getRow() throws SQLException {
		return delegator.getRow();
	}

	public RowId getRowId(int columnIndex) throws SQLException {
		return delegator.getRowId(columnIndex);
	}

	public RowId getRowId(String columnLabel)
			throws SQLException {
		return delegator.getRowId(columnLabel);
	}

	public short getShort(int columnIndex) throws SQLException {
		return delegator.getShort(columnIndex);
	}

	public short getShort(String columnLabel)
			throws SQLException {
		return delegator.getShort(columnLabel);
	}

	public SQLXML getSQLXML(int columnIndex) throws SQLException {
		return delegator.getSQLXML(columnIndex);
	}

	public SQLXML getSQLXML(String columnLabel)
			throws SQLException {
		return delegator.getSQLXML(columnLabel);
	}

	public Statement getStatement() throws SQLException {
		return delegator.getStatement();
	}

	public Time getTime(int columnIndex, Calendar cal)
			throws SQLException {
		return delegator.getTime(columnIndex, cal);
	}

	public Time getTime(int columnIndex) throws SQLException {
		return delegator.getTime(columnIndex);
	}

	public Time getTime(String columnLabel, Calendar cal)
			throws SQLException {
		return delegator.getTime(columnLabel, cal);
	}

	public Time getTime(String columnLabel) throws SQLException {
		return delegator.getTime(columnLabel);
	}

	public Timestamp getTimestamp(int columnIndex, Calendar cal)
			throws SQLException {
		return delegator.getTimestamp(columnIndex, cal);
	}

	public Timestamp getTimestamp(int columnIndex)
			throws SQLException {
		return delegator.getTimestamp(columnIndex);
	}

	public Timestamp getTimestamp(String columnLabel,
			Calendar cal) throws SQLException {
		return delegator.getTimestamp(columnLabel, cal);
	}

	public Timestamp getTimestamp(String columnLabel)
			throws SQLException {
		return delegator.getTimestamp(columnLabel);
	}

	public int getType() throws SQLException {
		return delegator.getType();
	}

	@SuppressWarnings("deprecation")
	public InputStream getUnicodeStream(int columnIndex)
			throws SQLException {
		return delegator.getUnicodeStream(columnIndex);
	}

	@SuppressWarnings("deprecation")
	public InputStream getUnicodeStream(String columnLabel)
			throws SQLException {
		return delegator.getUnicodeStream(columnLabel);
	}

	public URL getURL(int columnIndex) throws SQLException {
		return delegator.getURL(columnIndex);
	}

	public URL getURL(String columnLabel) throws SQLException {
		return delegator.getURL(columnLabel);
	}

	public SQLWarning getWarnings() throws SQLException {
		return delegator.getWarnings();
	}

	public void insertRow() throws SQLException {
		delegator.insertRow();
	}

	public boolean isAfterLast() throws SQLException {
		return delegator.isAfterLast();
	}

	public boolean isBeforeFirst() throws SQLException {
		return delegator.isBeforeFirst();
	}

	public boolean isClosed() throws SQLException {
		return delegator.isClosed();
	}

	public boolean isFirst() throws SQLException {
		return delegator.isFirst();
	}

	public boolean isLast() throws SQLException {
		return delegator.isLast();
	}

	public boolean last() throws SQLException {
		return delegator.last();
	}

	public void moveToCurrentRow() throws SQLException {
		delegator.moveToCurrentRow();
	}

	public void moveToInsertRow() throws SQLException {
		delegator.moveToInsertRow();
	}

	public boolean next() throws SQLException {
		return delegator.next();
	}

	public boolean previous() throws SQLException {
		return delegator.previous();
	}

	public void refreshRow() throws SQLException {
		delegator.refreshRow();
	}

	public boolean relative(int rows) throws SQLException {
		return delegator.relative(rows);
	}

	public boolean rowDeleted() throws SQLException {
		return delegator.rowDeleted();
	}

	public boolean rowInserted() throws SQLException {
		return delegator.rowInserted();
	}

	public boolean rowUpdated() throws SQLException {
		return delegator.rowUpdated();
	}

	public void setFetchDirection(int direction)
			throws SQLException {
		delegator.setFetchDirection(direction);
	}

	public void setFetchSize(int rows) throws SQLException {
		delegator.setFetchSize(rows);
	}

	public void updateArray(int columnIndex, Array x)
			throws SQLException {
		delegator.updateArray(columnIndex, x);
	}

	public void updateArray(String columnLabel, Array x)
			throws SQLException {
		delegator.updateArray(columnLabel, x);
	}

	public void updateAsciiStream(int columnIndex,
			InputStream x, int length) throws SQLException {
		delegator.updateAsciiStream(columnIndex, x, length);
	}

	public void updateAsciiStream(int columnIndex,
			InputStream x, long length) throws SQLException {
		delegator.updateAsciiStream(columnIndex, x, length);
	}

	public void updateAsciiStream(int columnIndex, InputStream x)
			throws SQLException {
		delegator.updateAsciiStream(columnIndex, x);
	}

	public void updateAsciiStream(String columnLabel,
			InputStream x, int length) throws SQLException {
		delegator.updateAsciiStream(columnLabel, x, length);
	}

	public void updateAsciiStream(String columnLabel,
			InputStream x, long length) throws SQLException {
		delegator.updateAsciiStream(columnLabel, x, length);
	}

	public void updateAsciiStream(String columnLabel,
			InputStream x) throws SQLException {
		delegator.updateAsciiStream(columnLabel, x);
	}

	public void updateBigDecimal(int columnIndex, BigDecimal x)
			throws SQLException {
		delegator.updateBigDecimal(columnIndex, x);
	}

	public void updateBigDecimal(String columnLabel, BigDecimal x)
			throws SQLException {
		delegator.updateBigDecimal(columnLabel, x);
	}

	public void updateBinaryStream(int columnIndex,
			InputStream x, int length) throws SQLException {
		delegator.updateBinaryStream(columnIndex, x, length);
	}

	public void updateBinaryStream(int columnIndex,
			InputStream x, long length) throws SQLException {
		delegator.updateBinaryStream(columnIndex, x, length);
	}

	public void updateBinaryStream(int columnIndex, InputStream x)
			throws SQLException {
		delegator.updateBinaryStream(columnIndex, x);
	}

	public void updateBinaryStream(String columnLabel,
			InputStream x, int length) throws SQLException {
		delegator.updateBinaryStream(columnLabel, x, length);
	}

	public void updateBinaryStream(String columnLabel,
			InputStream x, long length) throws SQLException {
		delegator.updateBinaryStream(columnLabel, x, length);
	}

	public void updateBinaryStream(String columnLabel,
			InputStream x) throws SQLException {
		delegator.updateBinaryStream(columnLabel, x);
	}

	public void updateBlob(int columnIndex, Blob x)
			throws SQLException {
		delegator.updateBlob(columnIndex, x);
	}

	public void updateBlob(int columnIndex,
			InputStream inputStream, long length)
			throws SQLException {
		delegator.updateBlob(columnIndex, inputStream, length);
	}

	public void updateBlob(int columnIndex,
			InputStream inputStream) throws SQLException {
		delegator.updateBlob(columnIndex, inputStream);
	}

	public void updateBlob(String columnLabel, Blob x)
			throws SQLException {
		delegator.updateBlob(columnLabel, x);
	}

	public void updateBlob(String columnLabel,
			InputStream inputStream, long length)
			throws SQLException {
		delegator.updateBlob(columnLabel, inputStream, length);
	}

	public void updateBlob(String columnLabel,
			InputStream inputStream) throws SQLException {
		delegator.updateBlob(columnLabel, inputStream);
	}

	public void updateBoolean(int columnIndex, boolean x)
			throws SQLException {
		delegator.updateBoolean(columnIndex, x);
	}

	public void updateBoolean(String columnLabel, boolean x)
			throws SQLException {
		delegator.updateBoolean(columnLabel, x);
	}

	public void updateByte(int columnIndex, byte x)
			throws SQLException {
		delegator.updateByte(columnIndex, x);
	}

	public void updateByte(String columnLabel, byte x)
			throws SQLException {
		delegator.updateByte(columnLabel, x);
	}

	public void updateBytes(int columnIndex, byte[] x)
			throws SQLException {
		delegator.updateBytes(columnIndex, x);
	}

	public void updateBytes(String columnLabel, byte[] x)
			throws SQLException {
		delegator.updateBytes(columnLabel, x);
	}

	public void updateCharacterStream(int columnIndex, Reader x,
			int length) throws SQLException {
		delegator.updateCharacterStream(columnIndex, x, length);
	}

	public void updateCharacterStream(int columnIndex, Reader x,
			long length) throws SQLException {
		delegator.updateCharacterStream(columnIndex, x, length);
	}

	public void updateCharacterStream(int columnIndex, Reader x)
			throws SQLException {
		delegator.updateCharacterStream(columnIndex, x);
	}

	public void updateCharacterStream(String columnLabel,
			Reader reader, int length) throws SQLException {
		delegator.updateCharacterStream(columnLabel, reader,
				length);
	}

	public void updateCharacterStream(String columnLabel,
			Reader reader, long length) throws SQLException {
		delegator.updateCharacterStream(columnLabel, reader,
				length);
	}

	public void updateCharacterStream(String columnLabel,
			Reader reader) throws SQLException {
		delegator.updateCharacterStream(columnLabel, reader);
	}

	public void updateClob(int columnIndex, Clob x)
			throws SQLException {
		delegator.updateClob(columnIndex, x);
	}

	public void updateClob(int columnIndex, Reader reader,
			long length) throws SQLException {
		delegator.updateClob(columnIndex, reader, length);
	}

	public void updateClob(int columnIndex, Reader reader)
			throws SQLException {
		delegator.updateClob(columnIndex, reader);
	}

	public void updateClob(String columnLabel, Clob x)
			throws SQLException {
		delegator.updateClob(columnLabel, x);
	}

	public void updateClob(String columnLabel, Reader reader,
			long length) throws SQLException {
		delegator.updateClob(columnLabel, reader, length);
	}

	public void updateClob(String columnLabel, Reader reader)
			throws SQLException {
		delegator.updateClob(columnLabel, reader);
	}

	public void updateDate(int columnIndex, Date x)
			throws SQLException {
		delegator.updateDate(columnIndex, x);
	}

	public void updateDate(String columnLabel, Date x)
			throws SQLException {
		delegator.updateDate(columnLabel, x);
	}

	public void updateDouble(int columnIndex, double x)
			throws SQLException {
		delegator.updateDouble(columnIndex, x);
	}

	public void updateDouble(String columnLabel, double x)
			throws SQLException {
		delegator.updateDouble(columnLabel, x);
	}

	public void updateFloat(int columnIndex, float x)
			throws SQLException {
		delegator.updateFloat(columnIndex, x);
	}

	public void updateFloat(String columnLabel, float x)
			throws SQLException {
		delegator.updateFloat(columnLabel, x);
	}

	public void updateInt(int columnIndex, int x)
			throws SQLException {
		delegator.updateInt(columnIndex, x);
	}

	public void updateInt(String columnLabel, int x)
			throws SQLException {
		delegator.updateInt(columnLabel, x);
	}

	public void updateLong(int columnIndex, long x)
			throws SQLException {
		delegator.updateLong(columnIndex, x);
	}

	public void updateLong(String columnLabel, long x)
			throws SQLException {
		delegator.updateLong(columnLabel, x);
	}

	public void updateNCharacterStream(int columnIndex,
			Reader x, long length) throws SQLException {
		delegator.updateNCharacterStream(columnIndex, x, length);
	}

	public void updateNCharacterStream(int columnIndex, Reader x)
			throws SQLException {
		delegator.updateNCharacterStream(columnIndex, x);
	}

	public void updateNCharacterStream(String columnLabel,
			Reader reader, long length) throws SQLException {
		delegator.updateNCharacterStream(columnLabel, reader,
				length);
	}

	public void updateNCharacterStream(String columnLabel,
			Reader reader) throws SQLException {
		delegator.updateNCharacterStream(columnLabel, reader);
	}

	public void updateNClob(int columnIndex, NClob clob)
			throws SQLException {
		delegator.updateNClob(columnIndex, clob);
	}

	public void updateNClob(int columnIndex, Reader reader,
			long length) throws SQLException {
		delegator.updateNClob(columnIndex, reader, length);
	}

	public void updateNClob(int columnIndex, Reader reader)
			throws SQLException {
		delegator.updateNClob(columnIndex, reader);
	}

	public void updateNClob(String columnLabel, NClob clob)
			throws SQLException {
		delegator.updateNClob(columnLabel, clob);
	}

	public void updateNClob(String columnLabel, Reader reader,
			long length) throws SQLException {
		delegator.updateNClob(columnLabel, reader, length);
	}

	public void updateNClob(String columnLabel, Reader reader)
			throws SQLException {
		delegator.updateNClob(columnLabel, reader);
	}

	public void updateNString(int columnIndex, String string)
			throws SQLException {
		delegator.updateNString(columnIndex, string);
	}

	public void updateNString(String columnLabel, String string)
			throws SQLException {
		delegator.updateNString(columnLabel, string);
	}

	public void updateNull(int columnIndex) throws SQLException {
		delegator.updateNull(columnIndex);
	}

	public void updateNull(String columnLabel)
			throws SQLException {
		delegator.updateNull(columnLabel);
	}

	public void updateObject(int columnIndex, Object x,
			int scaleOrLength) throws SQLException {
		delegator.updateObject(columnIndex, x, scaleOrLength);
	}

	public void updateObject(int columnIndex, Object x)
			throws SQLException {
		delegator.updateObject(columnIndex, x);
	}

	public void updateObject(String columnLabel, Object x,
			int scaleOrLength) throws SQLException {
		delegator.updateObject(columnLabel, x, scaleOrLength);
	}

	public void updateObject(String columnLabel, Object x)
			throws SQLException {
		delegator.updateObject(columnLabel, x);
	}

	public void updateRef(int columnIndex, Ref x)
			throws SQLException {
		delegator.updateRef(columnIndex, x);
	}

	public void updateRef(String columnLabel, Ref x)
			throws SQLException {
		delegator.updateRef(columnLabel, x);
	}

	public void updateRow() throws SQLException {
		delegator.updateRow();
	}

	public void updateRowId(int columnIndex, RowId x)
			throws SQLException {
		delegator.updateRowId(columnIndex, x);
	}

	public void updateRowId(String columnLabel, RowId x)
			throws SQLException {
		delegator.updateRowId(columnLabel, x);
	}

	public void updateShort(int columnIndex, short x)
			throws SQLException {
		delegator.updateShort(columnIndex, x);
	}

	public void updateShort(String columnLabel, short x)
			throws SQLException {
		delegator.updateShort(columnLabel, x);
	}

	public void updateSQLXML(int columnIndex, SQLXML xmlObject)
			throws SQLException {
		delegator.updateSQLXML(columnIndex, xmlObject);
	}

	public void updateSQLXML(String columnLabel, SQLXML xmlObject)
			throws SQLException {
		delegator.updateSQLXML(columnLabel, xmlObject);
	}

	public void updateString(int columnIndex, String x)
			throws SQLException {
		delegator.updateString(columnIndex, x);
	}

	public void updateString(String columnLabel, String x)
			throws SQLException {
		delegator.updateString(columnLabel, x);
	}

	public void updateTime(int columnIndex, Time x)
			throws SQLException {
		delegator.updateTime(columnIndex, x);
	}

	public void updateTime(String columnLabel, Time x)
			throws SQLException {
		delegator.updateTime(columnLabel, x);
	}

	public void updateTimestamp(int columnIndex, Timestamp x)
			throws SQLException {
		delegator.updateTimestamp(columnIndex, x);
	}

	public void updateTimestamp(String columnLabel, Timestamp x)
			throws SQLException {
		delegator.updateTimestamp(columnLabel, x);
	}

	public boolean wasNull() throws SQLException {
		return delegator.wasNull();
	}

}
